<?php

namespace Assetdocs\Company\Http\Controllers;

use App\Http\Controllers\Controller as BaseController;
use Assetdocs\Company\Interfaces\CompanyRepositoryInterface;
use Assetdocs\Company\Repositories\Presenter\CompanyItemTransformer;

/**
 * Pubic API controller class.
 */
class CompanyApiController extends BaseController
{
    /**
     * Constructor.
     *
     * @param type \Assetdocs\Company\Interfaces\CompanyRepositoryInterface $company
     *
     * @return type
     */
    public function __construct(CompanyRepositoryInterface $company)
    {
        $this->middleware('api');

        $this->repository = $company;
        parent::__construct();
    }

    /**
     * Show company's list.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function index()
    {
        $companies = $this->repository
            ->pushCriteria(new \Assetdocs\Company\Repositories\Criteria\CompanyPublicCriteria())
            ->setPresenter('\\Assetdocs\\Company\\Repositories\\Presenter\\CompanyListPresenter')
            ->scopeQuery(function($query){
                return $query->orderBy('id','DESC');
            })->paginate();

        $companies['code'] = 2000;
        return response()->json($companies)
                ->setStatusCode(200, 'INDEX_SUCCESS');
    }

    /**
     * Show company.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function show($slug)
    {
        $company = $this->repository
            ->scopeQuery(function($query) use ($slug) {
            return $query->orderBy('id','DESC')
                         ->where('slug', $slug);
        })->first(['*']);

        if (!is_null($company)) {
            $company         = $this->itemPresenter($module, new CompanyItemTransformer);
            $company['code'] = 2001;
            return response()->json($company)
                ->setStatusCode(200, 'SHOW_SUCCESS');
        } else {
            return response()->json([])
                ->setStatusCode(400, 'SHOW_ERROR');
        }

    }
}
