<?php

namespace Assetdocs\Company\Http\Controllers;

use App\Http\Controllers\Controller as BaseController;
use Assetdocs\Company\Interfaces\CompanyRepositoryInterface;

class CompanyController extends BaseController
{
    /**
     * Constructor.
     *
     * @param type \Assetdocs\Company\Interfaces\CompanyRepositoryInterface $company
     *
     * @return type
     */
    public function __construct(CompanyRepositoryInterface $company)
    {
        $this->middleware('web');
        $this->setupTheme(config('theme.themes.public.theme'), config('theme.themes.public.layout'));

        $this->repository = $company;
        parent::__construct();
    }

    /**
     * Show company's list.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function index()
    {
        $companies = $this->repository
            ->pushCriteria(new \Assetdocs\Company\Repositories\Criteria\CompanyPublicCriteria())
            ->scopeQuery(function($query){
                return $query->orderBy('id','DESC');
            })->paginate();

        return $this->theme->of('company::public.company.index', compact('companies'))->render();
    }

    /**
     * Show company.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function show($slug)
    {
        $company = $this->repository->scopeQuery(function($query) use ($slug) {
            return $query->orderBy('id','DESC')
                         ->where('slug', $slug);
        })->first(['*']);

        return $this->theme->of('company::public.company.show', compact('company'))->render();
    }
}
